@@ -544,7 +544,7 @@ void show_login_stats(char *user)
 		sprintf(devfile, "/dev/%s", (char *) ut->ut_line);
 		stat(devfile, &buf);
 
-		if ((buf.st_mode & S_IWGRP) && (buf.st_mode & S_IWOTH))
+		if (buf.st_mode & S_IWGRP)
 		    tty_list[times_on].writable = TRUE;
 		else
 		    tty_list[times_on].writable = FALSE;
